parse_args

Function parse_args 

pub fn parse_args() -> bool
Reads arguments from cargo run

Used to modify what is printed during runtime. Available options:

print_wv::(true/false) → Prints the worldview twice per second
print_err::(true/false) → Prints error messages
print_wrn::(true/false) → Prints warning messages
print_ok::(true/false) → Prints OK messages
print_info::(true/false) → Prints informational messages
print_else::(true/false) → Prints other messages, including master, slave, and color messages
debug:: → Disables all prints except error messages
help → Displays all possible arguments without starting the program

If no arguments are provided, all prints are enabled by default.

Secret options:
backup → Starts the program in backup-mode.