Module manager

Module manager 

Manager Module

This module is responsible for allocating tasks on the network. It executes the hall assigner script give under project resources.

Functions

start_manager
Main task for managing elevator coordination.