Manager Module
This module is responsible for allocating tasks on the network. It executes the hall assigner script give under project resources.
Functions
- start_
manager - Main task for managing elevator coordination.
This module is responsible for allocating tasks on the network. It executes the hall assigner script give under project resources.